@@ -94,16 +94,16 @@ OC.L10N.register(
     "Could not restore calendar or event" : "Не можа да се възстанови календар или събитие",
     "Do you really want to empty the trash bin?" : "Наистина ли искате да изпразните кошчето за боклук?",
     "Empty trash bin" : "Изпразване на кошчето за боклук",
-    "Trash bin" : "Кошче за бклук",
+    "Trash bin" : "Кошче",
     "Loading deleted items." : "Зареждане на изтрити елементи.",
     "You do not have any deleted items." : "Нямате изтрити елементи.",
     "Name" : "Име",
     "Deleted" : "Изтрито",
     "Restore" : "Възстановяне",
     "Delete permanently" : "Изтрий завинаги",
-    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето за боклук се изтриват след {numDays} дни","Елементите в кошчето за боклук се изтриват след {numDays} дни"],
+    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето за боклук се изтриват след {numDays} дни","Елементите в кошчето се изтриват след {numDays} дни"],
     "Could not update calendar order." : " Невъзможност да се актуализира записът в календара",
-    "Deck" : "Набор",
+    "Deck" : "Deck",
     "Hidden" : "Скрит",
     "An error occurred, unable to publish calendar." : "Възникна грешка, невъзможност да се публикува календар.",
     "An error occurred, unable to send email." : "Възникна грешка, невъзможност да се изпрати имейл",
@@ -247,7 +247,7 @@ OC.L10N.register(
     "seconds" : "секунди",
     "minutes" : "минути",
     "hours" : "часове",
-    "days" : "дена",
+    "days" : "дни",
     "weeks" : "седмици",
     "Choose a file to add as attachment" : "Избери файл за прикачване",
     "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
@@ -297,6 +297,7 @@ OC.L10N.register(
     "Required participant" : "Необходим участник",
     "Optional participant" : " Участник по желание",
     "Non-participant" : "Неучастник",
+    "Search for emails, users, contacts, contact groups or teams" : "Търси е-мейли, потребители, контакти, групи контакти или екипи.",
     "No match found" : "Няма намерено съвпадение",
     "(organizer)" : "(организатор)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да изпращате покани и да обработвате отговори, [отваряне на връзка] добавете вашия имейл адрес в личните настройки [затваряне на връзка].",
