@@ -8,27 +8,28 @@ OC.L10N.register(
     "Cheers!" : "Tudelu!",
     "Calendar" : "Kalender",
     "Prepare for %s" : "Klargjer for %s",
-    "New event" : "Ny hending",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Veke",
     "Month" : "Månad",
+    "Year" : "År",
     "Copy link" : "Kopier lenkje",
     "Edit" : "Rediger",
     "Delete" : "Slett",
     "New calendar" : "Ny kalender",
     "Export" : "Eksporter",
+    "Empty trash bin" : "Tøm søppel korg",
     "Name" : "Namn",
     "Deleted" : "Sletta",
     "Restore" : "Gjenopprett",
     "Delete permanently" : "Slett for godt",
-    "Empty trash bin" : "Tøm søppel korg",
     "Share link" : "Del lenkje",
     "can edit" : "kan endra",
     "Save" : "Lagre",
     "Cancel" : "Avbryt",
     "List view" : "Liste visning",
     "Actions" : "Handlingar",
+    "Update" : "Oppdater",
     "Location" : "Stad",
     "Description" : "Skildring",
     "to" : "til",
@@ -40,36 +41,31 @@ OC.L10N.register(
     "Friday" : "Fredag",
     "Saturday" : "Laurdag",
     "Sunday" : "Søndag",
-    "Update" : "Oppdater",
     "Your email address" : "Di epost-adresse",
     "Email" : "E-post",
+    "days" : "dagar",
     "Delete file" : "Slett fil",
     "Unknown" : "Ukjend",
     "Tentative" : "Førebels",
-    "Send email" : "Send e-post",
+    "Attendees" : "Deltakarar",
     "Repeat" : "Gjenta",
     "never" : "aldri",
     "after" : "etter",
-    "last" : "siste",
     "Room type" : "Romtype",
-    "More" : "Meir",
     "Global" : "Global",
     "Personal" : "Personleg",
     "Details" : "Detaljar",
-    "Attendees" : "Deltakarar",
     "Close" : "Lukk",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
+    "second" : "andre",
+    "last" : "siste",
     "Meeting room" : "Møterom",
     "Other" : "Anna",
     "When shared show full event" : "Når delt, vis heile hendinga",
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
     "Status" : "Status",
-    "Confirmed" : "Stadfesta",
-    "Money" : "Pengar",
-    "Talk" : "Prat",
-    "Mail" : "Post",
-    "Birthday" : "Bursdag"
+    "Confirmed" : "Stadfesta"
 },
 "nplurals=2; plural=(n != 1);");
